==> zopfli-0.0.0.tar.gz: zopfli-0.0.0/setup.py <==
#!/usr/bin/env python
"""
pyzopfli
======

Python bindings to zopfli
"""

from setuptools import setup, Extension

setup(
    name='zopfli',
    version='0.0.0',
    author='Adam DePrince',
    author_email='adeprince@nypublicradio.org',
    description='Zopfli module for python',
    long_description=__doc__,
    py_modules = [
        'zopfli',
        'zopfli.gzip',
        'zopfli.zlib',
        ],
    ext_modules = [Extension('zopfli.zopfli',
                             opts = "-O2 -W -Wall -Wextra -ansi -pedantic -lm",
                             sources = [
                'zopfli/blocksplitter.c',
                'zopfli/cache.c',
                'zopfli/deflate.c',
                'zopfli/gzip_container.c',
                'zopfli/squeeze.c',
                'zopfli/hash.c',
                'zopfli/katajainen.c',
                'zopfli/lz77.c', 
                'zopfli/tree.c',
                'zopfli/util.c',
                'zopfli/zlib_container.c',
                'zopfli/zopflimodule.c',
                ],
                             libraries = ['c']
                             )],
    packages = ["zopfli"],
    zip_safe=True,
    license='ASL',
    include_package_data=True,
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: Implementation :: CPython',
        'Topic :: System :: Archiving :: Compression',
        ],
    scripts = [
        ],
    url = "https://github.com/wnyc/pyzopfli",
    install_requires = [
        ]
)

==> zopfli-0.0.1.tar.gz: zopfli-0.0.1/setup.py <==
#!/usr/bin/env python
"""
pyzopfli
======

Python bindings to zopfli
"""

from setuptools import setup, Extension

setup(
    name='zopfli',
    version='0.0.1',
    author='Adam DePrince',
    author_email='adeprince@nypublicradio.org',
    description='Zopfli module for python',
    long_description=__doc__,
    py_modules = [
        'zopfli',
        'zopfli.gzip',
        'zopfli.zlib',
        ],
    ext_modules = [Extension('zopfli.zopfli',
                             opts = "-O2 -W -Wall -Wextra -ansi -pedantic -lm",
                             sources = [
                'zopfli/blocksplitter.c',
                'zopfli/cache.c',
                'zopfli/deflate.c',
                'zopfli/gzip_container.c',
                'zopfli/squeeze.c',
                'zopfli/hash.c',
                'zopfli/katajainen.c',
                'zopfli/lz77.c', 
                'zopfli/tree.c',
                'zopfli/util.c',
                'zopfli/zlib_container.c',
                'zopfli/zopflimodule.c',],
                             headers = [
                'zopfli/blocksplitter.h',
                'zopfli/cache.h',
                'zopfli/deflate.h',
                'zopfli/gzip_container.h',
                'zopfli/squeeze.h',
                'zopfli/hash.h',
                'zopfli/katajainen.h',
                'zopfli/lz77.h', 
                'zopfli/tree.h',
                'zopfli/util.h',
                'zopfli/zlib_container.h',
                ],
                             libraries = ['c']
                             )],
    packages = ["zopfli"],
    zip_safe=True,
    license='ASL',
    include_package_data=True,
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: Implementation :: CPython',
        'Topic :: System :: Archiving :: Compression',
        ],
    scripts = [
        ],
    url = "https://github.com/wnyc/pyzopfli",
    install_requires = [
        ]
)
